.. _interfaces_module:

:mod:`pyramid.interfaces`
----------------------------

.. automodule:: pyramid.interfaces

Event-Related Interfaces
++++++++++++++++++++++++

  .. autointerface:: IApplicationCreated

  .. autointerface:: INewRequest

  .. autointerface:: IContextFound

  .. autointerface:: INewResponse

  .. autointerface:: IBeforeRender

Other Interfaces
++++++++++++++++

  .. autointerface:: IAuthenticationPolicy
     :members:

  .. autointerface:: IAuthorizationPolicy
     :members:

  .. autointerface:: IExceptionResponse
     :members:

  .. autointerface:: IRoute
     :members:

  .. autointerface:: IRoutePregenerator
     :members:

  .. autointerface:: ISession
     :members:

  .. autointerface:: ISessionFactory
     :members:

  .. autointerface:: IRendererInfo
     :members:

  .. autointerface:: ITemplateRenderer
     :members:

  .. autointerface:: IViewMapperFactory
     :members:

  .. autointerface:: IViewMapper
     :members:

  .. autointerface:: IMultiDict
     :members:

  .. autointerface:: IResponse
     :members:

